@@ -41,13 +41,9 @@ along with this program. If not, see http://www.gnu.org/licenses/.
         ''' % __init__.__version__
         return
 
+def _parse_options():
 
-def main():
-    ''' entry point function for command line program '''
-    import sys
-    import os
     import optparse
-    import logging
 
     # parse options and arguments
     usage = 'usage: %prog [options] command'
@@ -59,17 +55,27 @@ def main():
 
     parser.add_option('-b', '--break', dest='breakstart',
                       action="store_true", default=False,
-                      help='"break" the program at the startup time')
+                      help='"break" the program at the startup time'
+                           '  default: false')
 
     parser.add_option('-m', '--monochrome', dest='monochrome',
                       action="store_true", default=False,
                       help='don\'t use color in output terminal')
 
-    parser.add_option('--version', dest='version',
+    parser.add_option('-v', '--version', dest='version',
                       action="store_true", default=False,
                       help='show version')
 
-    (options, args) = parser.parse_args()
+    return parser.parse_args()
+
+
+def main():
+    ''' entry point function for command line program '''
+    import sys
+    import os
+    import logging
+
+    options, args = _parse_options()
 
     if options.version:
         _printver()
@@ -127,14 +133,16 @@ def main():
 
     try:
         fd = os.open(options.output, os.O_WRONLY|os.O_CREAT|os.O_NONBLOCK)
-    except:
+    except OSError, e:
+        logging.exception(e)
         logging.exception("Connection closed.")
-        print "Cannot access output file or device: %s." % options.output
+        print("Cannot access output file or device.\n(%s)" % options.output)
         return
+
     try:
         if os.isatty(fd):
             if not os.path.exists(options.output):
-                print "The output device %s is not found." % options.output
+                print("The output device %s is not found." % options.output)
                 return
             if options.output == os.ttyname(0):
                 print ("The output device %s is busy (current TTY). "
@@ -167,18 +175,20 @@ def main():
                       termenc=termenc,
                       inputhandler=input.InputHandler(controller, tracer),
                       outputhandler=output.OutputHandler(controller, tracer))
-    except IOError:
+    except IOError, e:
+        logging.exception(e)
         logging.exception("Connection closed.")
-        print "connection closed."
-    except:
+        print("Connection closed.")
+    except Exception, e:
+        logging.exception(e)
         logging.exception("Aborted by exception.")
-        print ("trachet aborted by an uncaught exception."
-               " see $HOME/.trachet/log/log.txt.")
+        print('trachet aborted by an uncaught exception.'
+              ' see $HOME/.trachet/log/log.txt.')
     finally:
         try:
             tty.restore_term()
-        except:
-            pass
+        except Exception, e:
+            logging.exception(e)
 
 ''' main '''
 if __name__ == '__main__':
